

-- Edit box --
local editbox = CreateFrame('EditBox','InDemandEditBox')
	editbox:SetAutoFocus(false)
	editbox:ClearFocus()


-- Cached vars --
local pairs = pairs
local dostring = ChatEdit_SendText
local next = next


-- Timer exec --
local timers = {}

local total = 0
local function OnUpdate(this,elapsed)
	total = total + elapsed
	if total >= .1 then
		for name,t in pairs(timers) do
			t.delay = t.delay - total
			if t.delay <= 0 then
				editbox:SetText(t.cmd)
				dostring(editbox)
				editbox:Show()
				if t.rpt then
					t.delay = t.total
				else
					timers[name] = nil
				end
			end
		end
		if not next(timers) then
			this:SetScript('OnUpdate',nil)
		end
		total = 0
	end
end


-- Slash Cmds --
local function inSlash(input)
	local delay,name,cmd,args = input:match('^(%S+)%s+%[?([^%]]*)%]?%s*(/%S+)(.*)')
		delay = tonumber(delay)
	
	if not delay then
		ChatFrame1:AddMessage('|cff7fffff[InDemand]|r Usage: |cffffff7f/in <delay> [<name>] <command>|r (name optional).')
		return
	end
	
	if IsSecureCmd(cmd) then
		ChatFrame1:AddMessage('|cff7fffff[InDemand]|r |cffff7f7fError:|r Unable to execute secure command |cffffff7f'..cmd..'|r.')
		return
	end
	
	local timer = {
		delay = delay,
		cmd   = cmd..args,
	}
	
	if name == '' then
		name = tostring(timer)
		name = name:match('table: (.*)')
	else
		name = name:lower()
	end
	
	editbox:SetScript('OnUpdate',OnUpdate)
	
	timers[name] = timer
end

SLASH_IN1 = '/in'
SLASH_IN2 = '/delay'
SlashCmdList.IN = inSlash

SLASH_INDEMAND1 = '/ind'
SlashCmdList.INDEMAND = inSlash  -- Hackish fix. /in can collide with /in provided by Ace (damn you WowAce), causing the whole thing to break. So, I provide an alternate command on a separate entry. 

SLASH_RPT1 = '/repeat'
SLASH_RPT2 = '/rpt'
SlashCmdList.RPT = function(input)
	local name = input:match('^cancel (%S+)$')  -- are we cancelling?
	if name then
		name = name:lower()
		timers[name] = nil
		return
	end
	
	local delay,name,cmd,args = input:match('^(%S+)%s+%[([^%]]+)%]%s+(/%S+)(.*)')
		delay = tonumber(delay)
	
	if not delay or not name then
		ChatFrame1:AddMessage('|cff7fffff[InDemand]|r Usage: |cffffff7f/rpt <delay> [<name>] <command>|r or |cffffff7f/rpt cancel <name>|r.')
		return
	end
	
	if IsSecureCmd(cmd) then
		ChatFrame1:AddMessage('|cff7fffff[InDemand]|r |cffff7f7fError:|r Unable to execute secure command |cffffff7f'..cmd..'|r.')
		return
	end
	
	name = name:lower()
	
	timers[name] = {
		delay = delay,
		total = delay,
		rpt   = true,
		cmd   = cmd..args,
	}
	
	editbox:SetScript('OnUpdate',OnUpdate)
end
